checkRequire("Lua_InfinityHallLayerItem");
checkRequire("Lua_InfinityHallSingleRewardItem");
Lua_InfinityHallWindow = class("Lua_InfinityHallWindow", Lua_Window);
function Lua_InfinityHallWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_InfinityHallWindow";
	self.skinName = "InfinityHallWindow_skin";
	self.isFullSizeWin = true;
	self.isFullPaving = true;
	self.showBlackMask = true;
	self.showBackBtn = true;
end

function Lua_InfinityHallWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.dateIcon:setEnable(false);
	DataCenter.infinityHallData.bInfinityHallOpened = true;
	self.curType = DataCenter.infinityHallData.curType;

	self.roundBar:setMaxValue(1);
	self.roundBar:setValue(0);

	self.itemBg:SetDimensions(720, 711 + self.adaptHeight);
	self.itemList = Lua_DragList.new(self.content, 702, 680 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -73, 0);
	self.itemList.tweenId = 2021;
	self.itemList.delayTween = true;
	self.itemList:setListCell(Lua_InfinityHallLayerItem, 702, 150, 1);
	self.itemList:setCellSpacing(0, 15);

	self.redPint_reward = Lua_RedPointIcon.new(self.content, Lua_RedPointList.InfinityHall_Reward_Single);
	self.redPint_reward:setRectAnchor(1);
	self.redPint_reward:setLocation(-200, -295);

	self.redPint_support = Lua_RedPointIcon.new(self.supportObject, Lua_RedPointList.InfinityHall_Support);
	self.redPint_support:setLocation(342, 202.5);

	self.btnInfo = Array();
	self.btnInfo:add({ textAtlas = "infinity_hall_altas", textNormalSprite = "ui_wqzd_button_001_p", textSelectedSprite = "ui_wqzd_button_002_p" });
	self.btnInfo:add({ textAtlas = "infinity_hall_altas", textNormalSprite = "ui_wqzd_button_001_n", textSelectedSprite = "ui_wqzd_button_002_n" });

	self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.btnList:setRectAnchor(7);
	self.btnList:setLocation(240, 53.5, 0);
	self.btnList.pivot = -1;
	self.btnList:setButtonStyle("common_altas_1", "ui_common_button_001_b", "ui_common_button_001_b", 118, 108, 0.01, 1);
	self.btnList:setButtonLine("common_altas_1", "ui_common_line_011", 2, 108, 0, 0, 1);
	self.btnList:setButtonItem(120, 108);
	self.btnList:setClickCallBack(self, self.onButtonClick);
	self.btnList:setData(self.btnInfo);
	self.btnList:setSelected(self.curType);

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.checkRank:addClickFuntion(self, self.onCheckRank);
	self.checkReward:addClickFuntion(self, self.onCheckReward);
	self.checkStore:setEnable(false);
	self.checkStore:addClickFuntion(self, self.onCheckStore);
	self.daliyReward:addClickFuntion(self, self.onDailyReward);
	self.btnChallenge:addClickFuntion(self, self.onBtnChallengeClick);
	self.checkSupport:addClickFuntion(self, self.onCheckSupport);
	
	self:addLuaEvent("INFINITYHALL_INFO", self, self.updateShowInfo);
	self:addLuaEvent("INFINITYHALL_REWARD", self, self.updateShowReward);
	self:addLuaEvent("INFINITYHALL_LAYER_INFO", self, self.updateLayerInfo);
	self:addLuaEvent("FIGHTPLAY_ENTER", self, self.checkIsFighting);
	self:addLuaEvent("FIGHTPLAY_COMPLETE", self, self.checkIsFighting);
end

function Lua_InfinityHallWindow:onBackBtnClick()
	DataCenter.funcPathUtil:gotoFunction(1047, true);
end

function Lua_InfinityHallWindow:dispose()
	DataCenter.preLoadData:removeBySign("Lua_InfinityHallWindow", self, self.onSceneShow);
	if self.rankArr ~= nil then
		self.rankArr:dispose();
		self.rankArr:clear();
		self.rankArr = nil;
	end
	if self.rewardArr ~= nil then
		self.rewardArr:dispose();
		self.rewardArr:clear();
		self.rewardArr = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.btnInfo ~= nil then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	if self.redPint_reward ~= nil then
		self.redPint_reward:dispose();
		self.redPint_reward = nil;
	end
	if self.redPint_fight ~= nil then
		self.redPint_fight:dispose();
		self.redPint_fight = nil;
	end
	if self.redPint_support ~= nil then
		self.redPint_support:dispose();
		self.redPint_support = nil;
	end
	if self.redPint_daily ~= nil then
		self.redPint_daily:dispose();
		self.redPint_daily = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_InfinityHallWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.itemBg:SetDimensions(720, 711 + self.adaptHeight);
	self.itemList:setContentRect(702, 680 + self.adaptHeight);
end

function Lua_InfinityHallWindow:onButtonClick(index)
	if self.curType == index then
		self:updateShowInfo();
	else
		self.curType = index;
		Lua_ProxyManager.getProxy("Lua_InfinityHallProxy"):sInfinityHall(index);
	end
end

function Lua_InfinityHallWindow:updateShowInfo()
	local data = DataCenter.infinityHallData;
	local vo = data:getTypeInfo(self.curType);
	self:updateRankInfo(vo.rank_list);

	local index;
	for i = 1, vo.layerArr:getSize() do
		if vo.layerArr[i].id == vo.cur_floor then
			index = i;
			break;
		end
	end
	index = index == nil and 1 or index;
	self.itemList.showTween = true;
	self.itemList:setArrayData(vo.layerArr);
	self.itemList:moveToIndex(index, true, true);
	self.itemList:setSelectClick(index);
	self.itemList:setSelected(index);

	if self.curType == 1 then
		-- self.dateIcon:setAltas("infinity_hall_altas", "ui_wqzd_title_02");
		self.redPint_reward:changeRedPoint(Lua_RedPointList.InfinityHall_Reward_Single);
		self.supportObject:SetActive(false);
	elseif self.curType == 2 then
		-- self.dateIcon:setAltas("infinity_hall_altas", "ui_wqzd_title_06");
		self.redPint_reward:changeRedPoint(Lua_RedPointList.InfinityHall_Reward_Team);

		self.supportObject:SetActive(true);
		if data.choose_hero == nil or tonumber(data.choose_hero.unique_id) <= 0 then
			self.supportBg:setEnable(true);
			self.supportTips:setEnable(true);
		else
			self.supportBg:setEnable(false);
			self.supportTips:setEnable(false);
		end
	end
	-- self.dateIcon:resetSize();
	if self.curType ~= data.curType or data.daily_stage_id == nil or data.daily_stage_id <= 0 or data.draw_state == 0 then
		self.daliyReward:setGray(true);
		if self.redPint_daily ~= nil then
			self.redPint_daily:setEnable(false);
		end
	else
		self.daliyReward:setGray(false);
		if data.draw_state == 1 then
			if self.redPint_daily == nil then
				self.redPint_daily = Lua_RedPointIcon.new(self.content);
				self.redPint_daily:setRectAnchor(1);
				self.redPint_daily:setLocation(335, -132);
				self.redPint_daily:createRedPointEff();
				self.redPint_daily:updateRedPointShow(true)
			end
			self.redPint_daily:setEnable(true);
		else
			if self.redPint_daily ~= nil then
				self.redPint_daily:setEnable(false);
			end
		end
	end
end

function Lua_InfinityHallWindow:updateRankInfo(list)
	if self.rankArr == nil then
		self.rankArr = Array();
	end

	local item;
	for i = 1, 3 do
		item = self.rankArr[i];
		if item == nil then
			item = Lua_InfinityHallRankMiniItem.new(self.rankObject);
			self.rankArr:add(item);
		end
		item:setLocation(-213, -79 - i * 46, 0);
		if list == nil or #list < i then
			item:setData(i, nil);
		else
			item:setData(i, list[i]);
		end
	end
end

function Lua_InfinityHallWindow:updateLayerInfo(data)
	self.data = data;
	if data == nil then
		return;
	end

	if self.curType == DataCenter.infinityHallData.curType and data.state == 1 then
		if self.redPint_fight == nil then
			self.redPint_fight = Lua_RedPointIcon.new(self.content, Lua_RedPointList.InfinityHall_Fight);
			self.redPint_fight:setRectAnchor(7);
			self.redPint_fight:setLocation(80, 205);
		end
		self.redPint_fight:setEnable(true);
	else
		if self.redPint_fight ~= nil then
			self.redPint_fight:setEnable(false);
		end
	end

	self:updateShowReward();
	self.forceText.text = LanUtil.formateStr(304006, tostring(data.force));
	self:updateBtnState();
end

function Lua_InfinityHallWindow:checkIsFighting(templateId)
	if self.curType == 1 then
		if templateId == Lua_FightDefine.TEMPLATE_ID_INFINITYHALL_1 then
			self:updateBtnState();
		end
	elseif self.curType == 2 then
		if templateId == Lua_FightDefine.TEMPLATE_ID_INFINITYHALL_2 then
			self:updateBtnState();
		end
	end
end

function Lua_InfinityHallWindow:updateBtnState()
	if self.data == nil then
		return;
	end

	self.recordId = 0;
	if self.curType == 1 then
		self.recordId = DataCenter.fightData:getRecordIdByTemplateId(Lua_FightDefine.TEMPLATE_ID_INFINITYHALL_1);
	elseif self.curType == 2 then
		self.recordId = DataCenter.fightData:getRecordIdByTemplateId(Lua_FightDefine.TEMPLATE_ID_INFINITYHALL_2);
	end
	
	if self.recordId > 0 then
		self.btnChallenge:setLangValue(304011);
	else
		self.btnChallenge:setLangValue(304012);
	end

	local state = self.recordId > 0 or self.data.state == 2
	if not state then
		state = self.curType ~= DataCenter.infinityHallData.curType
	end
	if not state then
		state = DataCenter.infinityHallData.daily_times >= DataCenter.infinityHallUtil.dailyLimit
	end
	self.btnChallenge:setGray(state);
end

function Lua_InfinityHallWindow:updateShowReward()
	if self.data == nil then
		return;
	end
	self:updateReward(self.data.round, self.data.rewardArr);

	local showList = self.itemList.showList;
	for i = 1, showList:getSize() do
		showList[i]:updateRedPoint();
	end
end

function Lua_InfinityHallWindow:updateReward(round, arr)
	if self.rewardArr == nil then
		self.rewardArr = Array();
	end
	local len = self.rewardArr:getSize();
	local dataLen = arr:getSize();
	local maxValue = arr[dataLen].round;
	local value = 0;
	local index = 1;
	if round >= maxValue then
		value = maxValue;
	else
		local stepSpace = maxValue / dataLen;
		for i = 1, dataLen do
			if arr[i].round >= round then
				index = i;
				break;
			end
		end
		value = value + stepSpace * (index - 1);
		local num;
		if index <= 1 then
			num = stepSpace / arr[index].round;
			value = value + round * num;
		else
			num = stepSpace / (arr[index].round - arr[index - 1].round);
			value = value + (round - arr[index - 1].round) * num;
		end
	end
	self.roundBar:setMaxValue(maxValue);
	self.roundBar:setValue(value);

	local maxLen = dataLen > len and dataLen or len;
	local item;
	for i = 1, maxLen do
		item = self.rewardArr[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_InfinityHallSingleRewardItem.new(self.content);
				self.rewardArr:add(item);
			else
				item:setEnable(true);
			end
			item:setRectAnchor(4);
			item:setLocation(i / dataLen * 550 - 235, -325.5, 0);
			item:setRectAnchor(1);
			item:setScale(0.7, 0.7);
			item:setCanClick(true);
			item:setData(arr[i], 1);
		end
	end
end

function Lua_InfinityHallWindow:onCheckHelp(go)
	local tipsData = { posX = -210, posY = -170, des = LanUtil.getValue(304007) };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_InfinityHallWindow:onCheckRank(go)
	Lua_WindowUtil.openWin("Lua_InfinityHallRankWindow", Lua_WinParam.ACTION_OPEN, self.curType);
end

function Lua_InfinityHallWindow:onCheckReward(go)
	Lua_WindowUtil.openWin("Lua_InfinityHallRewardWindow", Lua_WinParam.ACTION_OPEN, self.curType);
end

function Lua_InfinityHallWindow:onCheckStore(go)
	DataCenter.funcPathUtil:gotoFunction(1027)
end

function Lua_InfinityHallWindow:onDailyReward(go)
	local data = DataCenter.infinityHallData;
	if self.curType ~= data.curType then
		if self.curType == 1 then
			OperateAlert.show(LanUtil.formateStr(304031, LanUtil.getValue(304027)));
		else
			OperateAlert.show(LanUtil.formateStr(304031, LanUtil.getValue(304028)));
		end
		return;
	end	

	if data.daily_stage_id == nil or data.daily_stage_id <= 0 or data.draw_state == 0 then
		if self.curType == 1 then
			OperateAlert.show(LanUtil.formateStr(304029, LanUtil.getValue(304027)));
		else
			OperateAlert.show(LanUtil.formateStr(304029, LanUtil.getValue(304028)));
		end
		return;
	end

	Lua_WindowUtil.openWin("Lua_InfinityHallDailyRewardWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_InfinityHallWindow:onBtnChallengeClick(go)
	if self.data == nil then
		return;
	end

	if self.curType ~= DataCenter.infinityHallData.curType then
		OperateAlert.showLangValue(304008);
		return;
	end

	if self.recordId > 0 then
		DataCenter.fightData:showFightToStageByRid(self.recordId);
		return;
	end

	if DataCenter.infinityHallData.daily_times >= DataCenter.infinityHallUtil.dailyLimit then
		OperateAlert.showLangValue(304040);
		return;
	end

	if self.data.state == 0 then
		OperateAlert.showLangValue(304009);
	elseif self.data.state == 1 then
		local sceneId = 0;
		if self.curType == 1 then
			sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_INFINITYHALL_1);
		elseif self.curType == 2 then
			sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_INFINITYHALL_2);
		end
		if sceneId > 0 then
			DataCenter.preLoadData:preShowScene("Lua_InfinityHallWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, nil, sceneId, 0);
		end
	elseif self.data.state == 2 then
		OperateAlert.showLangValue(304010);
	end
end

function Lua_InfinityHallWindow:onSceneShow(param)
	if self.curType == 1 then
		local data = { template_id = Lua_FightDefine.TEMPLATE_ID_INFINITYHALL_1, monster_player_id = self.data.config.monser_id };
		Lua_WindowUtil.openWin("Lua_InfinityHallIndividualWindow", Lua_WinParam.ACTION_OPEN, data);
	elseif self.curType == 2 then
		local data = { template_id = Lua_FightDefine.TEMPLATE_ID_INFINITYHALL_2, monster_player_id = self.data.config.monser_id };
		Lua_WindowUtil.openWin("Lua_InfinityHallTeamWindow", Lua_WinParam.ACTION_OPEN, data);
	end
end

function Lua_InfinityHallWindow:onCheckSupport(go)
	Lua_WindowUtil.openWin("Lua_InfinityHallSupportWindow", Lua_WinParam.ACTION_OPEN);
end




















Lua_InfinityHallRankMiniItem = class("Lua_InfinityHallRankMiniItem", Lua_DisplayObject);
function Lua_InfinityHallRankMiniItem:ctor(p)
	self:superCall("ctor", p, "InfinityHallRankMiniItem_skin");
end

function Lua_InfinityHallRankMiniItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_InfinityHallRankMiniItem:dispose()
	self:superCall("dispose");
end

function Lua_InfinityHallRankMiniItem:setData(rank, data)
	self.rankIcon:setAltas("common_altas_4", "ui_wqzd_title_0"..rank + 2);
	if data == nil then
		self.nameText:setLangValue(304037);
		self.layerText.text = nil;
	else
		self.nameText.text = data.player_show.name;
		self.layerText.text = LanUtil.formateStr(304000, tostring(data.value), tostring(data.sub_value));
	end
end