Lua_InfinityHallSingleRewardItem = class("Lua_InfinityHallSingleRewardItem", Lua_DisplayObject);
function Lua_InfinityHallSingleRewardItem:ctor(p)
	self:superCall("ctor", p, "InfinityHallSingleRewardItem_skin");
end

function Lua_InfinityHallSingleRewardItem:buildShowItem()
	self:superCall("buildShowItem");
	self.minX = 0;
	self.maxX = 0;
	self.minY = 0;
	self.maxY = 0;

	self.maskIcon:setEnable(false);
	self.stateIcon:setEnable(false);
	self.roundText:setEnable(false);

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setSiblingIndex(0);
end

function Lua_InfinityHallSingleRewardItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_InfinityHallSingleRewardItem:setScale(scaleX, scaleY)
	self._scaleX = scaleX;
	self._scaleY = scaleY;
	self.itemIcon:setScale(scaleX, scaleY, 1);
	self.maskIcon:setScale(scaleX, scaleY, 1);
end

function Lua_InfinityHallSingleRewardItem:setCanClick(bClick)
	if bClick then
		self.itemIcon:setClick(self, self.onClick);
	else
		self.itemIcon:setClick(nil, nil);
	end
end

function Lua_InfinityHallSingleRewardItem:checkInBound(touchX, touchY)
	local posX = self.posX or 0
	local posY = self.posY or 0
	local scaleX = self.scaleX or 1
	local scaleY = self.scaleY or 1
	local minX = posX - 106 / 2 * scaleX
	local maxX = posX + 106 / 2 * scaleX
	local minY = posY - 106 / 2 * scaleY
	local maxY = posY + 106 / 2 * scaleY
	if touchX >= minX and touchX <= maxX and touchY >= minY and touchY <= maxY then
		return true
	end
	return false
end

function Lua_InfinityHallSingleRewardItem:setData(data, style)
	self.data = data;
	if data == nil then
		return;
	end

	local tvo = Lua_ToolVo.createToolVo(data.reward[1][1], data.reward[1][2]);
	self.itemIcon:setData(tvo);

	local state = DataCenter.infinityHallData:getRewardState(data.id);
	self.maskIcon:setEnable(state == 2);

	if style == 1 then
		self.stateIcon:setEnable(true);
		if state >= 1 then
			self.stateIcon:setAltas("infinity_hall_altas", "ui_wqzd_button_010_p");
		else
			self.stateIcon:setAltas("infinity_hall_altas", "ui_wqzd_button_010_n");
		end
		self.roundText:setEnable(true);
		self.roundText.text = LanUtil.formateStr(304005, tostring(data.round));
	else
		self.stateIcon:setEnable(false);
		self.roundText:setEnable(false);
	end

	self:showRedPoint(state == 1);
end

function Lua_InfinityHallSingleRewardItem:showRedPoint(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			if self.scaleX == 1 then
				self.redPoint:setLocation(50, 45, 0);
			else
				self.redPoint:setLocation(35, 30, 0);
			end
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_InfinityHallSingleRewardItem:onClick(data)
	if self.data == nil then
		return;
	end

	local state = DataCenter.infinityHallData:getRewardState(self.data.id);
	if state == 1 then
		Lua_ProxyManager.getProxy("Lua_InfinityHallProxy"):sReceiveAward(self.data.type, self.data.floor);
	else
		DataCenter.packUtil:showItemInfo(self.itemIcon.data);
	end
end